# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import backend_nvme_tcp_pb2 as backend__nvme__tcp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class NVMfRemoteControllerServiceStub(object):
    """Back End (network-facing) APIs. NVMe/TCP and NVMe/RoCEv2 protocols are covered by this service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNVMfRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NVMfRemoteControllerService/CreateNVMfRemoteController',
                request_serializer=backend__nvme__tcp__pb2.CreateNVMfRemoteControllerRequest.SerializeToString,
                response_deserializer=backend__nvme__tcp__pb2.NVMfRemoteController.FromString,
                )
        self.DeleteNVMfRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NVMfRemoteControllerService/DeleteNVMfRemoteController',
                request_serializer=backend__nvme__tcp__pb2.DeleteNVMfRemoteControllerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNVMfRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NVMfRemoteControllerService/UpdateNVMfRemoteController',
                request_serializer=backend__nvme__tcp__pb2.UpdateNVMfRemoteControllerRequest.SerializeToString,
                response_deserializer=backend__nvme__tcp__pb2.NVMfRemoteController.FromString,
                )
        self.ListNVMfRemoteControllers = channel.unary_unary(
                '/opi_api.storage.v1.NVMfRemoteControllerService/ListNVMfRemoteControllers',
                request_serializer=backend__nvme__tcp__pb2.ListNVMfRemoteControllersRequest.SerializeToString,
                response_deserializer=backend__nvme__tcp__pb2.ListNVMfRemoteControllersResponse.FromString,
                )
        self.GetNVMfRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NVMfRemoteControllerService/GetNVMfRemoteController',
                request_serializer=backend__nvme__tcp__pb2.GetNVMfRemoteControllerRequest.SerializeToString,
                response_deserializer=backend__nvme__tcp__pb2.NVMfRemoteController.FromString,
                )
        self.NVMfRemoteControllerReset = channel.unary_unary(
                '/opi_api.storage.v1.NVMfRemoteControllerService/NVMfRemoteControllerReset',
                request_serializer=backend__nvme__tcp__pb2.NVMfRemoteControllerResetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.NVMfRemoteControllerStats = channel.unary_unary(
                '/opi_api.storage.v1.NVMfRemoteControllerService/NVMfRemoteControllerStats',
                request_serializer=backend__nvme__tcp__pb2.NVMfRemoteControllerStatsRequest.SerializeToString,
                response_deserializer=backend__nvme__tcp__pb2.NVMfRemoteControllerStatsResponse.FromString,
                )


class NVMfRemoteControllerServiceServicer(object):
    """Back End (network-facing) APIs. NVMe/TCP and NVMe/RoCEv2 protocols are covered by this service.
    """

    def CreateNVMfRemoteController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNVMfRemoteController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNVMfRemoteController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNVMfRemoteControllers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNVMfRemoteController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NVMfRemoteControllerReset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NVMfRemoteControllerStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NVMfRemoteControllerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNVMfRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNVMfRemoteController,
                    request_deserializer=backend__nvme__tcp__pb2.CreateNVMfRemoteControllerRequest.FromString,
                    response_serializer=backend__nvme__tcp__pb2.NVMfRemoteController.SerializeToString,
            ),
            'DeleteNVMfRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNVMfRemoteController,
                    request_deserializer=backend__nvme__tcp__pb2.DeleteNVMfRemoteControllerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNVMfRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNVMfRemoteController,
                    request_deserializer=backend__nvme__tcp__pb2.UpdateNVMfRemoteControllerRequest.FromString,
                    response_serializer=backend__nvme__tcp__pb2.NVMfRemoteController.SerializeToString,
            ),
            'ListNVMfRemoteControllers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNVMfRemoteControllers,
                    request_deserializer=backend__nvme__tcp__pb2.ListNVMfRemoteControllersRequest.FromString,
                    response_serializer=backend__nvme__tcp__pb2.ListNVMfRemoteControllersResponse.SerializeToString,
            ),
            'GetNVMfRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNVMfRemoteController,
                    request_deserializer=backend__nvme__tcp__pb2.GetNVMfRemoteControllerRequest.FromString,
                    response_serializer=backend__nvme__tcp__pb2.NVMfRemoteController.SerializeToString,
            ),
            'NVMfRemoteControllerReset': grpc.unary_unary_rpc_method_handler(
                    servicer.NVMfRemoteControllerReset,
                    request_deserializer=backend__nvme__tcp__pb2.NVMfRemoteControllerResetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'NVMfRemoteControllerStats': grpc.unary_unary_rpc_method_handler(
                    servicer.NVMfRemoteControllerStats,
                    request_deserializer=backend__nvme__tcp__pb2.NVMfRemoteControllerStatsRequest.FromString,
                    response_serializer=backend__nvme__tcp__pb2.NVMfRemoteControllerStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.NVMfRemoteControllerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NVMfRemoteControllerService(object):
    """Back End (network-facing) APIs. NVMe/TCP and NVMe/RoCEv2 protocols are covered by this service.
    """

    @staticmethod
    def CreateNVMfRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NVMfRemoteControllerService/CreateNVMfRemoteController',
            backend__nvme__tcp__pb2.CreateNVMfRemoteControllerRequest.SerializeToString,
            backend__nvme__tcp__pb2.NVMfRemoteController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNVMfRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NVMfRemoteControllerService/DeleteNVMfRemoteController',
            backend__nvme__tcp__pb2.DeleteNVMfRemoteControllerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNVMfRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NVMfRemoteControllerService/UpdateNVMfRemoteController',
            backend__nvme__tcp__pb2.UpdateNVMfRemoteControllerRequest.SerializeToString,
            backend__nvme__tcp__pb2.NVMfRemoteController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNVMfRemoteControllers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NVMfRemoteControllerService/ListNVMfRemoteControllers',
            backend__nvme__tcp__pb2.ListNVMfRemoteControllersRequest.SerializeToString,
            backend__nvme__tcp__pb2.ListNVMfRemoteControllersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNVMfRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NVMfRemoteControllerService/GetNVMfRemoteController',
            backend__nvme__tcp__pb2.GetNVMfRemoteControllerRequest.SerializeToString,
            backend__nvme__tcp__pb2.NVMfRemoteController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NVMfRemoteControllerReset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NVMfRemoteControllerService/NVMfRemoteControllerReset',
            backend__nvme__tcp__pb2.NVMfRemoteControllerResetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NVMfRemoteControllerStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NVMfRemoteControllerService/NVMfRemoteControllerStats',
            backend__nvme__tcp__pb2.NVMfRemoteControllerStatsRequest.SerializeToString,
            backend__nvme__tcp__pb2.NVMfRemoteControllerStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2022 Dell Inc, or its subsidiaries.

import grpc

from .proto.v1 import (
    frontend_nvme_pcie_pb2,
    frontend_nvme_pcie_pb2_grpc,
    object_key_pb2,
    opicommon_pb2,
    uuid_pb2,
)


def list_nvme_subsystems(address):
    print(
        "tbd",
        address,
        grpc.StatusCode.UNIMPLEMENTED,
        frontend_nvme_pcie_pb2.ListNVMeSubsystemsRequest(),
    )


def create_nvme_subsystem(address):
    channel = grpc.insecure_channel(address)
    stub = frontend_nvme_pcie_pb2_grpc.FrontendNvmeServiceStub(channel)
    try:
        res = stub.CreateNVMeSubsystem(
            request=frontend_nvme_pcie_pb2.CreateNVMeSubsystemRequest(
                nv_me_subsystem=frontend_nvme_pcie_pb2.NVMeSubsystem(
                    spec=frontend_nvme_pcie_pb2.NVMeSubsystemSpec(
                        id=object_key_pb2.ObjectKey(value="opi-subsystem"),
                        model_number="OPI Model",
                        serial_number="OPI SN",
                        max_namespaces=10,
                        nqn="nqn.2022-09.io.spdk:opi1",
                    )
                )
            )
        )
        print(res)
    except grpc.RpcError as e:
        print(e)


def create_nvme_controller(address):
    channel = grpc.insecure_channel(address)
    stub = frontend_nvme_pcie_pb2_grpc.FrontendNvmeServiceStub(channel)
    try:
        res = stub.CreateNVMeController(
            request=frontend_nvme_pcie_pb2.CreateNVMeControllerRequest(
                nv_me_controller=frontend_nvme_pcie_pb2.NVMeController(
                    spec=frontend_nvme_pcie_pb2.NVMeControllerSpec(
                        id=object_key_pb2.ObjectKey(value="opi-ctrl"),
                        subsystem_id=object_key_pb2.ObjectKey(value="opi-subsystem"),
                        pcie_id=opicommon_pb2.PciEndpoint(
                            physical_function=1, virtual_function=2, port_id=3
                        ),
                        max_nsq=5,
                        max_ncq=6,
                        sqes=7,
                        cqes=8,
                        nvme_controller_id=1,
                    )
                )
            )
        )
        print(res)
    except grpc.RpcError as e:
        print(e)


def create_nvme_namespace(address):
    channel = grpc.insecure_channel(address)
    stub = frontend_nvme_pcie_pb2_grpc.FrontendNvmeServiceStub(channel)
    try:
        res = stub.CreateNVMeNamespace(
            request=frontend_nvme_pcie_pb2.CreateNVMeNamespaceRequest(
                nv_me_namespace=frontend_nvme_pcie_pb2.NVMeNamespace(
                    spec=frontend_nvme_pcie_pb2.NVMeNamespaceSpec(
                        id=object_key_pb2.ObjectKey(value="opi-ns"),
                        subsystem_id=object_key_pb2.ObjectKey(value="opi-subsystem"),
                        volume_id=object_key_pb2.ObjectKey(value="Malloc1"),
                        uuid=uuid_pb2.Uuid(
                            value="1b4e28ba-2fa1-11d2-883f-b9a761bde3fb"
                        ),
                        nguid="1b4e28ba-2fa1-11d2-883f-b9a761bde3fb",
                        eui64=1967554867335598546,
                        host_nsid=1,
                    )
                )
            )
        )
        print(res)
    except grpc.RpcError as e:
        print(e)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: object_key.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10object_key.proto\x12\x11opi_api.common.v1\"\x1a\n\tObjectKey\x12\r\n\x05value\x18\x01 \x01(\tBU\n\x11opi_api.common.v1B\x0eObjectKeyProtoP\x01Z.github.com/opiproject/opi-api/common/v1/gen/gob\x06proto3')



_OBJECTKEY = DESCRIPTOR.message_types_by_name['ObjectKey']
ObjectKey = _reflection.GeneratedProtocolMessageType('ObjectKey', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTKEY,
  '__module__' : 'object_key_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.common.v1.ObjectKey)
  })
_sym_db.RegisterMessage(ObjectKey)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021opi_api.common.v1B\016ObjectKeyProtoP\001Z.github.com/opiproject/opi-api/common/v1/gen/go'
  _OBJECTKEY._serialized_start=39
  _OBJECTKEY._serialized_end=65
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import backend_null_pb2 as backend__null__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class NullDebugServiceStub(object):
    """Back End (network-facing) APIs. This is debug interface for null block devices.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNullDebug = channel.unary_unary(
                '/opi_api.storage.v1.NullDebugService/CreateNullDebug',
                request_serializer=backend__null__pb2.CreateNullDebugRequest.SerializeToString,
                response_deserializer=backend__null__pb2.NullDebug.FromString,
                )
        self.DeleteNullDebug = channel.unary_unary(
                '/opi_api.storage.v1.NullDebugService/DeleteNullDebug',
                request_serializer=backend__null__pb2.DeleteNullDebugRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNullDebug = channel.unary_unary(
                '/opi_api.storage.v1.NullDebugService/UpdateNullDebug',
                request_serializer=backend__null__pb2.UpdateNullDebugRequest.SerializeToString,
                response_deserializer=backend__null__pb2.NullDebug.FromString,
                )
        self.ListNullDebugs = channel.unary_unary(
                '/opi_api.storage.v1.NullDebugService/ListNullDebugs',
                request_serializer=backend__null__pb2.ListNullDebugsRequest.SerializeToString,
                response_deserializer=backend__null__pb2.ListNullDebugsResponse.FromString,
                )
        self.GetNullDebug = channel.unary_unary(
                '/opi_api.storage.v1.NullDebugService/GetNullDebug',
                request_serializer=backend__null__pb2.GetNullDebugRequest.SerializeToString,
                response_deserializer=backend__null__pb2.NullDebug.FromString,
                )
        self.NullDebugStats = channel.unary_unary(
                '/opi_api.storage.v1.NullDebugService/NullDebugStats',
                request_serializer=backend__null__pb2.NullDebugStatsRequest.SerializeToString,
                response_deserializer=backend__null__pb2.NullDebugStatsResponse.FromString,
                )


class NullDebugServiceServicer(object):
    """Back End (network-facing) APIs. This is debug interface for null block devices.
    """

    def CreateNullDebug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNullDebug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNullDebug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNullDebugs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNullDebug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NullDebugStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NullDebugServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNullDebug': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNullDebug,
                    request_deserializer=backend__null__pb2.CreateNullDebugRequest.FromString,
                    response_serializer=backend__null__pb2.NullDebug.SerializeToString,
            ),
            'DeleteNullDebug': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNullDebug,
                    request_deserializer=backend__null__pb2.DeleteNullDebugRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNullDebug': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNullDebug,
                    request_deserializer=backend__null__pb2.UpdateNullDebugRequest.FromString,
                    response_serializer=backend__null__pb2.NullDebug.SerializeToString,
            ),
            'ListNullDebugs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNullDebugs,
                    request_deserializer=backend__null__pb2.ListNullDebugsRequest.FromString,
                    response_serializer=backend__null__pb2.ListNullDebugsResponse.SerializeToString,
            ),
            'GetNullDebug': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNullDebug,
                    request_deserializer=backend__null__pb2.GetNullDebugRequest.FromString,
                    response_serializer=backend__null__pb2.NullDebug.SerializeToString,
            ),
            'NullDebugStats': grpc.unary_unary_rpc_method_handler(
                    servicer.NullDebugStats,
                    request_deserializer=backend__null__pb2.NullDebugStatsRequest.FromString,
                    response_serializer=backend__null__pb2.NullDebugStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.NullDebugService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NullDebugService(object):
    """Back End (network-facing) APIs. This is debug interface for null block devices.
    """

    @staticmethod
    def CreateNullDebug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullDebugService/CreateNullDebug',
            backend__null__pb2.CreateNullDebugRequest.SerializeToString,
            backend__null__pb2.NullDebug.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNullDebug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullDebugService/DeleteNullDebug',
            backend__null__pb2.DeleteNullDebugRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNullDebug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullDebugService/UpdateNullDebug',
            backend__null__pb2.UpdateNullDebugRequest.SerializeToString,
            backend__null__pb2.NullDebug.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNullDebugs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullDebugService/ListNullDebugs',
            backend__null__pb2.ListNullDebugsRequest.SerializeToString,
            backend__null__pb2.ListNullDebugsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNullDebug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullDebugService/GetNullDebug',
            backend__null__pb2.GetNullDebugRequest.SerializeToString,
            backend__null__pb2.NullDebug.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NullDebugStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NullDebugService/NullDebugStats',
            backend__null__pb2.NullDebugStatsRequest.SerializeToString,
            backend__null__pb2.NullDebugStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import frontend_virtio_scsi_pb2 as frontend__virtio__scsi__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class FrontendVirtioScsiServiceStub(object):
    """Front End (host-facing) APIs. Mostly used for Virtio-scsi emulation and host presentation as alternative to Virtio-blk.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateVirtioScsiTarget = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/CreateVirtioScsiTarget',
                request_serializer=frontend__virtio__scsi__pb2.CreateVirtioScsiTargetRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiTarget.FromString,
                )
        self.DeleteVirtioScsiTarget = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/DeleteVirtioScsiTarget',
                request_serializer=frontend__virtio__scsi__pb2.DeleteVirtioScsiTargetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateVirtioScsiTarget = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/UpdateVirtioScsiTarget',
                request_serializer=frontend__virtio__scsi__pb2.UpdateVirtioScsiTargetRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiTarget.FromString,
                )
        self.ListVirtioScsiTargets = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/ListVirtioScsiTargets',
                request_serializer=frontend__virtio__scsi__pb2.ListVirtioScsiTargetsRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.ListVirtioScsiTargetsResponse.FromString,
                )
        self.GetVirtioScsiTarget = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/GetVirtioScsiTarget',
                request_serializer=frontend__virtio__scsi__pb2.GetVirtioScsiTargetRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiTarget.FromString,
                )
        self.VirtioScsiTargetStats = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/VirtioScsiTargetStats',
                request_serializer=frontend__virtio__scsi__pb2.VirtioScsiTargetStatsRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiTargetStatsResponse.FromString,
                )
        self.CreateVirtioScsiController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/CreateVirtioScsiController',
                request_serializer=frontend__virtio__scsi__pb2.CreateVirtioScsiControllerRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiController.FromString,
                )
        self.DeleteVirtioScsiController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/DeleteVirtioScsiController',
                request_serializer=frontend__virtio__scsi__pb2.DeleteVirtioScsiControllerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateVirtioScsiController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/UpdateVirtioScsiController',
                request_serializer=frontend__virtio__scsi__pb2.UpdateVirtioScsiControllerRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiController.FromString,
                )
        self.ListVirtioScsiControllers = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/ListVirtioScsiControllers',
                request_serializer=frontend__virtio__scsi__pb2.ListVirtioScsiControllersRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.ListVirtioScsiControllersResponse.FromString,
                )
        self.GetVirtioScsiController = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/GetVirtioScsiController',
                request_serializer=frontend__virtio__scsi__pb2.GetVirtioScsiControllerRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiController.FromString,
                )
        self.VirtioScsiControllerStats = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/VirtioScsiControllerStats',
                request_serializer=frontend__virtio__scsi__pb2.VirtioScsiControllerStatsRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiControllerStatsResponse.FromString,
                )
        self.CreateVirtioScsiLun = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/CreateVirtioScsiLun',
                request_serializer=frontend__virtio__scsi__pb2.CreateVirtioScsiLunRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiLun.FromString,
                )
        self.DeleteVirtioScsiLun = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/DeleteVirtioScsiLun',
                request_serializer=frontend__virtio__scsi__pb2.DeleteVirtioScsiLunRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateVirtioScsiLun = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/UpdateVirtioScsiLun',
                request_serializer=frontend__virtio__scsi__pb2.UpdateVirtioScsiLunRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiLun.FromString,
                )
        self.ListVirtioScsiLuns = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/ListVirtioScsiLuns',
                request_serializer=frontend__virtio__scsi__pb2.ListVirtioScsiLunsRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.ListVirtioScsiLunsResponse.FromString,
                )
        self.GetVirtioScsiLun = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/GetVirtioScsiLun',
                request_serializer=frontend__virtio__scsi__pb2.GetVirtioScsiLunRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiLun.FromString,
                )
        self.VirtioScsiLunStats = channel.unary_unary(
                '/opi_api.storage.v1.FrontendVirtioScsiService/VirtioScsiLunStats',
                request_serializer=frontend__virtio__scsi__pb2.VirtioScsiLunStatsRequest.SerializeToString,
                response_deserializer=frontend__virtio__scsi__pb2.VirtioScsiLunStatsResponse.FromString,
                )


class FrontendVirtioScsiServiceServicer(object):
    """Front End (host-facing) APIs. Mostly used for Virtio-scsi emulation and host presentation as alternative to Virtio-blk.
    """

    def CreateVirtioScsiTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVirtioScsiTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVirtioScsiTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVirtioScsiTargets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtioScsiTarget(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VirtioScsiTargetStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateVirtioScsiController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVirtioScsiController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVirtioScsiController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVirtioScsiControllers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtioScsiController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VirtioScsiControllerStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateVirtioScsiLun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVirtioScsiLun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVirtioScsiLun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVirtioScsiLuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVirtioScsiLun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VirtioScsiLunStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FrontendVirtioScsiServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateVirtioScsiTarget': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVirtioScsiTarget,
                    request_deserializer=frontend__virtio__scsi__pb2.CreateVirtioScsiTargetRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiTarget.SerializeToString,
            ),
            'DeleteVirtioScsiTarget': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVirtioScsiTarget,
                    request_deserializer=frontend__virtio__scsi__pb2.DeleteVirtioScsiTargetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateVirtioScsiTarget': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVirtioScsiTarget,
                    request_deserializer=frontend__virtio__scsi__pb2.UpdateVirtioScsiTargetRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiTarget.SerializeToString,
            ),
            'ListVirtioScsiTargets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVirtioScsiTargets,
                    request_deserializer=frontend__virtio__scsi__pb2.ListVirtioScsiTargetsRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.ListVirtioScsiTargetsResponse.SerializeToString,
            ),
            'GetVirtioScsiTarget': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtioScsiTarget,
                    request_deserializer=frontend__virtio__scsi__pb2.GetVirtioScsiTargetRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiTarget.SerializeToString,
            ),
            'VirtioScsiTargetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.VirtioScsiTargetStats,
                    request_deserializer=frontend__virtio__scsi__pb2.VirtioScsiTargetStatsRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiTargetStatsResponse.SerializeToString,
            ),
            'CreateVirtioScsiController': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVirtioScsiController,
                    request_deserializer=frontend__virtio__scsi__pb2.CreateVirtioScsiControllerRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiController.SerializeToString,
            ),
            'DeleteVirtioScsiController': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVirtioScsiController,
                    request_deserializer=frontend__virtio__scsi__pb2.DeleteVirtioScsiControllerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateVirtioScsiController': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVirtioScsiController,
                    request_deserializer=frontend__virtio__scsi__pb2.UpdateVirtioScsiControllerRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiController.SerializeToString,
            ),
            'ListVirtioScsiControllers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVirtioScsiControllers,
                    request_deserializer=frontend__virtio__scsi__pb2.ListVirtioScsiControllersRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.ListVirtioScsiControllersResponse.SerializeToString,
            ),
            'GetVirtioScsiController': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtioScsiController,
                    request_deserializer=frontend__virtio__scsi__pb2.GetVirtioScsiControllerRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiController.SerializeToString,
            ),
            'VirtioScsiControllerStats': grpc.unary_unary_rpc_method_handler(
                    servicer.VirtioScsiControllerStats,
                    request_deserializer=frontend__virtio__scsi__pb2.VirtioScsiControllerStatsRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiControllerStatsResponse.SerializeToString,
            ),
            'CreateVirtioScsiLun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVirtioScsiLun,
                    request_deserializer=frontend__virtio__scsi__pb2.CreateVirtioScsiLunRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiLun.SerializeToString,
            ),
            'DeleteVirtioScsiLun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVirtioScsiLun,
                    request_deserializer=frontend__virtio__scsi__pb2.DeleteVirtioScsiLunRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateVirtioScsiLun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVirtioScsiLun,
                    request_deserializer=frontend__virtio__scsi__pb2.UpdateVirtioScsiLunRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiLun.SerializeToString,
            ),
            'ListVirtioScsiLuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVirtioScsiLuns,
                    request_deserializer=frontend__virtio__scsi__pb2.ListVirtioScsiLunsRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.ListVirtioScsiLunsResponse.SerializeToString,
            ),
            'GetVirtioScsiLun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVirtioScsiLun,
                    request_deserializer=frontend__virtio__scsi__pb2.GetVirtioScsiLunRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiLun.SerializeToString,
            ),
            'VirtioScsiLunStats': grpc.unary_unary_rpc_method_handler(
                    servicer.VirtioScsiLunStats,
                    request_deserializer=frontend__virtio__scsi__pb2.VirtioScsiLunStatsRequest.FromString,
                    response_serializer=frontend__virtio__scsi__pb2.VirtioScsiLunStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.FrontendVirtioScsiService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FrontendVirtioScsiService(object):
    """Front End (host-facing) APIs. Mostly used for Virtio-scsi emulation and host presentation as alternative to Virtio-blk.
    """

    @staticmethod
    def CreateVirtioScsiTarget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/CreateVirtioScsiTarget',
            frontend__virtio__scsi__pb2.CreateVirtioScsiTargetRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiTarget.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVirtioScsiTarget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/DeleteVirtioScsiTarget',
            frontend__virtio__scsi__pb2.DeleteVirtioScsiTargetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVirtioScsiTarget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/UpdateVirtioScsiTarget',
            frontend__virtio__scsi__pb2.UpdateVirtioScsiTargetRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiTarget.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVirtioScsiTargets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/ListVirtioScsiTargets',
            frontend__virtio__scsi__pb2.ListVirtioScsiTargetsRequest.SerializeToString,
            frontend__virtio__scsi__pb2.ListVirtioScsiTargetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVirtioScsiTarget(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/GetVirtioScsiTarget',
            frontend__virtio__scsi__pb2.GetVirtioScsiTargetRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiTarget.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VirtioScsiTargetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/VirtioScsiTargetStats',
            frontend__virtio__scsi__pb2.VirtioScsiTargetStatsRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiTargetStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateVirtioScsiController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/CreateVirtioScsiController',
            frontend__virtio__scsi__pb2.CreateVirtioScsiControllerRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVirtioScsiController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/DeleteVirtioScsiController',
            frontend__virtio__scsi__pb2.DeleteVirtioScsiControllerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVirtioScsiController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/UpdateVirtioScsiController',
            frontend__virtio__scsi__pb2.UpdateVirtioScsiControllerRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVirtioScsiControllers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/ListVirtioScsiControllers',
            frontend__virtio__scsi__pb2.ListVirtioScsiControllersRequest.SerializeToString,
            frontend__virtio__scsi__pb2.ListVirtioScsiControllersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVirtioScsiController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/GetVirtioScsiController',
            frontend__virtio__scsi__pb2.GetVirtioScsiControllerRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VirtioScsiControllerStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/VirtioScsiControllerStats',
            frontend__virtio__scsi__pb2.VirtioScsiControllerStatsRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiControllerStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateVirtioScsiLun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/CreateVirtioScsiLun',
            frontend__virtio__scsi__pb2.CreateVirtioScsiLunRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiLun.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVirtioScsiLun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/DeleteVirtioScsiLun',
            frontend__virtio__scsi__pb2.DeleteVirtioScsiLunRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVirtioScsiLun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/UpdateVirtioScsiLun',
            frontend__virtio__scsi__pb2.UpdateVirtioScsiLunRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiLun.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVirtioScsiLuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/ListVirtioScsiLuns',
            frontend__virtio__scsi__pb2.ListVirtioScsiLunsRequest.SerializeToString,
            frontend__virtio__scsi__pb2.ListVirtioScsiLunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVirtioScsiLun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/GetVirtioScsiLun',
            frontend__virtio__scsi__pb2.GetVirtioScsiLunRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiLun.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VirtioScsiLunStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.FrontendVirtioScsiService/VirtioScsiLunStats',
            frontend__virtio__scsi__pb2.VirtioScsiLunStatsRequest.SerializeToString,
            frontend__virtio__scsi__pb2.VirtioScsiLunStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: middleend.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
import object_key_pb2 as object__key__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fmiddleend.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x10object_key.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\xbe\x01\n\x0f\x45ncryptedVolume\x12\x39\n\x13\x65ncrypted_volume_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12/\n\tvolume_id\x18\x02 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\x32\n\x06\x63ipher\x18\x04 \x01(\x0e\x32\".opi_api.storage.v1.EncryptionType\"\xbb\x01\n\x1c\x43reateEncryptedVolumeRequest\x12:\n\x06parent\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n\"opi_api.storage.v1/EncryptedVolume\x12\x42\n\x10\x65ncrypted_volume\x18\x02 \x01(\x0b\x32#.opi_api.storage.v1.EncryptedVolumeB\x03\xe0\x41\x02\x12\x1b\n\x13\x65ncrypted_volume_id\x18\x03 \x01(\t\"X\n\x1c\x44\x65leteEncryptedVolumeRequest\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n\"opi_api.storage.v1/EncryptedVolume\"\x8e\x01\n\x1cUpdateEncryptedVolumeRequest\x12=\n\x10\x65ncrypted_volume\x18\x01 \x01(\x0b\x32#.opi_api.storage.v1.EncryptedVolume\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x80\x01\n\x1bListEncryptedVolumesRequest\x12:\n\x06parent\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n\"opi_api.storage.v1/EncryptedVolume\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"w\n\x1cListEncryptedVolumesResponse\x12>\n\x11\x65ncrypted_volumes\x18\x01 \x03(\x0b\x32#.opi_api.storage.v1.EncryptedVolume\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"U\n\x19GetEncryptedVolumeRequest\x12\x38\n\x04name\x18\x01 \x01(\tB*\xe0\x41\x02\xfa\x41$\n\"opi_api.storage.v1/EncryptedVolume\"X\n\x1b\x45ncryptedVolumeStatsRequest\x12\x39\n\x13\x65ncrypted_volume_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"\x89\x01\n\x1c\x45ncryptedVolumeStatsResponse\x12\x39\n\x13\x65ncrypted_volume_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats2\x80\x08\n\x10MiddleendService\x12\xcf\x01\n\x15\x43reateEncryptedVolume\x12\x30.opi_api.storage.v1.CreateEncryptedVolumeRequest\x1a#.opi_api.storage.v1.EncryptedVolume\"_\x82\xd3\xe4\x93\x02+\"\x17/v1/{parent=subsystems}:\x10\x65ncrypted_volume\xda\x41+parent,encrypted_volume,encrypted_volume_id\x12\x8d\x01\n\x15\x44\x65leteEncryptedVolume\x12\x30.opi_api.storage.v1.DeleteEncryptedVolumeRequest\x1a\x16.google.protobuf.Empty\"*\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/{name=volumes}/{volume}\xda\x41\x04name\x12\xcf\x01\n\x15UpdateEncryptedVolume\x12\x30.opi_api.storage.v1.UpdateEncryptedVolumeRequest\x1a#.opi_api.storage.v1.EncryptedVolume\"_\x82\xd3\xe4\x93\x02:2&/v1/{encrypted_volume.name=subsystems}:\x10\x65ncrypted_volume\xda\x41\x1c\x65ncrypted_volume,update_mask\x12\xa0\x01\n\x14ListEncryptedVolumes\x12/.opi_api.storage.v1.ListEncryptedVolumesRequest\x1a\x30.opi_api.storage.v1.ListEncryptedVolumesResponse\"%\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/{parent=volumes}\xda\x41\x06parent\x12\x97\x01\n\x12GetEncryptedVolume\x12-.opi_api.storage.v1.GetEncryptedVolumeRequest\x1a#.opi_api.storage.v1.EncryptedVolume\"-\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{name=subsystems}/{volume}\xda\x41\x04name\x12{\n\x14\x45ncryptedVolumeStats\x12/.opi_api.storage.v1.EncryptedVolumeStatsRequest\x1a\x30.opi_api.storage.v1.EncryptedVolumeStatsResponse\"\x00\x42]\n\x12opi_api.storage.v1B\x0eMiddleendProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')



_ENCRYPTEDVOLUME = DESCRIPTOR.message_types_by_name['EncryptedVolume']
_CREATEENCRYPTEDVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['CreateEncryptedVolumeRequest']
_DELETEENCRYPTEDVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['DeleteEncryptedVolumeRequest']
_UPDATEENCRYPTEDVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['UpdateEncryptedVolumeRequest']
_LISTENCRYPTEDVOLUMESREQUEST = DESCRIPTOR.message_types_by_name['ListEncryptedVolumesRequest']
_LISTENCRYPTEDVOLUMESRESPONSE = DESCRIPTOR.message_types_by_name['ListEncryptedVolumesResponse']
_GETENCRYPTEDVOLUMEREQUEST = DESCRIPTOR.message_types_by_name['GetEncryptedVolumeRequest']
_ENCRYPTEDVOLUMESTATSREQUEST = DESCRIPTOR.message_types_by_name['EncryptedVolumeStatsRequest']
_ENCRYPTEDVOLUMESTATSRESPONSE = DESCRIPTOR.message_types_by_name['EncryptedVolumeStatsResponse']
EncryptedVolume = _reflection.GeneratedProtocolMessageType('EncryptedVolume', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDVOLUME,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.EncryptedVolume)
  })
_sym_db.RegisterMessage(EncryptedVolume)

CreateEncryptedVolumeRequest = _reflection.GeneratedProtocolMessageType('CreateEncryptedVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENCRYPTEDVOLUMEREQUEST,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateEncryptedVolumeRequest)
  })
_sym_db.RegisterMessage(CreateEncryptedVolumeRequest)

DeleteEncryptedVolumeRequest = _reflection.GeneratedProtocolMessageType('DeleteEncryptedVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENCRYPTEDVOLUMEREQUEST,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteEncryptedVolumeRequest)
  })
_sym_db.RegisterMessage(DeleteEncryptedVolumeRequest)

UpdateEncryptedVolumeRequest = _reflection.GeneratedProtocolMessageType('UpdateEncryptedVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENCRYPTEDVOLUMEREQUEST,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateEncryptedVolumeRequest)
  })
_sym_db.RegisterMessage(UpdateEncryptedVolumeRequest)

ListEncryptedVolumesRequest = _reflection.GeneratedProtocolMessageType('ListEncryptedVolumesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENCRYPTEDVOLUMESREQUEST,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListEncryptedVolumesRequest)
  })
_sym_db.RegisterMessage(ListEncryptedVolumesRequest)

ListEncryptedVolumesResponse = _reflection.GeneratedProtocolMessageType('ListEncryptedVolumesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENCRYPTEDVOLUMESRESPONSE,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListEncryptedVolumesResponse)
  })
_sym_db.RegisterMessage(ListEncryptedVolumesResponse)

GetEncryptedVolumeRequest = _reflection.GeneratedProtocolMessageType('GetEncryptedVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENCRYPTEDVOLUMEREQUEST,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetEncryptedVolumeRequest)
  })
_sym_db.RegisterMessage(GetEncryptedVolumeRequest)

EncryptedVolumeStatsRequest = _reflection.GeneratedProtocolMessageType('EncryptedVolumeStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDVOLUMESTATSREQUEST,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.EncryptedVolumeStatsRequest)
  })
_sym_db.RegisterMessage(EncryptedVolumeStatsRequest)

EncryptedVolumeStatsResponse = _reflection.GeneratedProtocolMessageType('EncryptedVolumeStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDVOLUMESTATSRESPONSE,
  '__module__' : 'middleend_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.EncryptedVolumeStatsResponse)
  })
_sym_db.RegisterMessage(EncryptedVolumeStatsResponse)

_MIDDLEENDSERVICE = DESCRIPTOR.services_by_name['MiddleendService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\016MiddleendProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATEENCRYPTEDVOLUMEREQUEST.fields_by_name['parent']._options = None
  _CREATEENCRYPTEDVOLUMEREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A$\n\"opi_api.storage.v1/EncryptedVolume'
  _CREATEENCRYPTEDVOLUMEREQUEST.fields_by_name['encrypted_volume']._options = None
  _CREATEENCRYPTEDVOLUMEREQUEST.fields_by_name['encrypted_volume']._serialized_options = b'\340A\002'
  _DELETEENCRYPTEDVOLUMEREQUEST.fields_by_name['name']._options = None
  _DELETEENCRYPTEDVOLUMEREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A$\n\"opi_api.storage.v1/EncryptedVolume'
  _LISTENCRYPTEDVOLUMESREQUEST.fields_by_name['parent']._options = None
  _LISTENCRYPTEDVOLUMESREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A$\n\"opi_api.storage.v1/EncryptedVolume'
  _GETENCRYPTEDVOLUMEREQUEST.fields_by_name['name']._options = None
  _GETENCRYPTEDVOLUMEREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A$\n\"opi_api.storage.v1/EncryptedVolume'
  _MIDDLEENDSERVICE.methods_by_name['CreateEncryptedVolume']._options = None
  _MIDDLEENDSERVICE.methods_by_name['CreateEncryptedVolume']._serialized_options = b'\202\323\344\223\002+\"\027/v1/{parent=subsystems}:\020encrypted_volume\332A+parent,encrypted_volume,encrypted_volume_id'
  _MIDDLEENDSERVICE.methods_by_name['DeleteEncryptedVolume']._options = None
  _MIDDLEENDSERVICE.methods_by_name['DeleteEncryptedVolume']._serialized_options = b'\202\323\344\223\002\035*\033/v1/{name=volumes}/{volume}\332A\004name'
  _MIDDLEENDSERVICE.methods_by_name['UpdateEncryptedVolume']._options = None
  _MIDDLEENDSERVICE.methods_by_name['UpdateEncryptedVolume']._serialized_options = b'\202\323\344\223\002:2&/v1/{encrypted_volume.name=subsystems}:\020encrypted_volume\332A\034encrypted_volume,update_mask'
  _MIDDLEENDSERVICE.methods_by_name['ListEncryptedVolumes']._options = None
  _MIDDLEENDSERVICE.methods_by_name['ListEncryptedVolumes']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/{parent=volumes}\332A\006parent'
  _MIDDLEENDSERVICE.methods_by_name['GetEncryptedVolume']._options = None
  _MIDDLEENDSERVICE.methods_by_name['GetEncryptedVolume']._serialized_options = b'\202\323\344\223\002 \022\036/v1/{name=subsystems}/{volume}\332A\004name'
  _ENCRYPTEDVOLUME._serialized_start=253
  _ENCRYPTEDVOLUME._serialized_end=443
  _CREATEENCRYPTEDVOLUMEREQUEST._serialized_start=446
  _CREATEENCRYPTEDVOLUMEREQUEST._serialized_end=633
  _DELETEENCRYPTEDVOLUMEREQUEST._serialized_start=635
  _DELETEENCRYPTEDVOLUMEREQUEST._serialized_end=723
  _UPDATEENCRYPTEDVOLUMEREQUEST._serialized_start=726
  _UPDATEENCRYPTEDVOLUMEREQUEST._serialized_end=868
  _LISTENCRYPTEDVOLUMESREQUEST._serialized_start=871
  _LISTENCRYPTEDVOLUMESREQUEST._serialized_end=999
  _LISTENCRYPTEDVOLUMESRESPONSE._serialized_start=1001
  _LISTENCRYPTEDVOLUMESRESPONSE._serialized_end=1120
  _GETENCRYPTEDVOLUMEREQUEST._serialized_start=1122
  _GETENCRYPTEDVOLUMEREQUEST._serialized_end=1207
  _ENCRYPTEDVOLUMESTATSREQUEST._serialized_start=1209
  _ENCRYPTEDVOLUMESTATSREQUEST._serialized_end=1297
  _ENCRYPTEDVOLUMESTATSRESPONSE._serialized_start=1300
  _ENCRYPTEDVOLUMESTATSRESPONSE._serialized_end=1437
  _MIDDLEENDSERVICE._serialized_start=1440
  _MIDDLEENDSERVICE._serialized_end=2464
# @@protoc_insertion_point(module_scope)



# SPDX-License-Identifier: Apache-2.0
# Copyright (c) 2022 Dell Inc, or its subsidiaries.

import grpc

from .proto.v1 import ipsec_pb2, ipsec_pb2_grpc


def get_stats(address):
    channel = grpc.insecure_channel(address)
    stub = ipsec_pb2_grpc.IPsecStub(channel)
    a = stub.IPsecVersion(ipsec_pb2.IPsecVersionReq())
    b = stub.IPsecStats(ipsec_pb2.IPsecStatsReq())
    c = stub.IPsecListConns(ipsec_pb2.IPsecListConnsReq(ike="tun1_0_0"))
    d = stub.IPsecListSas(ipsec_pb2.IPsecListSasReq(ike="tun1_0_0"))
    e = stub.IPsecListCerts(ipsec_pb2.IPsecListCertsReq())
    print(a, b, c, d, e)


def create_new_tunnel(address):
    channel = grpc.insecure_channel(address)
    stub = ipsec_pb2_grpc.IPsecStub(channel)
    # connection_1 = stub.IPsecLoadConn(tun1_0_0)
    # connection_2 = stub.IPsecLoadConn(tun1_0_1)
    print(
        "tbd",
        stub,
        grpc.StatusCode.UNIMPLEMENTED,
        ipsec_pb2.IPsecStatsReq(),
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ipsec.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bipsec.proto\x12\x13opi_api.security.v1\"\xf1\x01\n\tProposals\x12\x38\n\ncrypto_alg\x18\x01 \x03(\x0e\x32$.opi_api.security.v1.CryptoAlgorithm\x12\x36\n\tinteg_alg\x18\x02 \x03(\x0e\x32#.opi_api.security.v1.IntegAlgorithm\x12\x36\n\x03prf\x18\x03 \x03(\x0e\x32).opi_api.security.v1.PseudoRandomFunction\x12:\n\x08\x64hgroups\x18\x04 \x03(\x0e\x32(.opi_api.security.v1.DiffieHellmanGroups\"\x13\n\x04Vips\x12\x0b\n\x03vip\x18\x01 \x03(\t\"\x15\n\x05Pools\x12\x0c\n\x04pool\x18\x01 \x03(\t\"\x15\n\x05\x43\x65rts\x12\x0c\n\x04\x63\x65rt\x18\x01 \x03(\t\"\x19\n\x07PubKeys\x12\x0e\n\x06pubkey\x18\x01 \x03(\t\"\x17\n\x06Groups\x12\r\n\x05group\x18\x01 \x03(\t\"!\n\nCertPolicy\x12\x13\n\x0b\x63\x65rt_policy\x18\x01 \x03(\t\"\x19\n\x07\x43\x61\x43\x65rts\x12\x0e\n\x06\x63\x61\x63\x65rt\x18\x01 \x03(\t\"\xd0\x01\n\tLocalAuth\x12+\n\x04\x61uth\x18\x01 \x01(\x0e\x32\x1d.opi_api.security.v1.AuthType\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06\x65\x61p_id\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x61\x61_id\x18\x04 \x01(\t\x12\x10\n\x08xauth_id\x18\x05 \x01(\t\x12)\n\x05\x63\x65rts\x18\x06 \x01(\x0b\x32\x1a.opi_api.security.v1.Certs\x12-\n\x07pubkeys\x18\x07 \x01(\x0b\x32\x1c.opi_api.security.v1.PubKeys\"\xc2\x02\n\nRemoteAuth\x12+\n\x04\x61uth\x18\x01 \x01(\x0e\x32\x1d.opi_api.security.v1.AuthType\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06\x65\x61p_id\x18\x03 \x01(\t\x12+\n\x06groups\x18\x04 \x01(\x0b\x32\x1b.opi_api.security.v1.Groups\x12\x34\n\x0b\x63\x65rt_policy\x18\x05 \x01(\x0b\x32\x1f.opi_api.security.v1.CertPolicy\x12)\n\x05\x63\x65rts\x18\x06 \x01(\x0b\x32\x1a.opi_api.security.v1.Certs\x12.\n\x08\x63\x61_certs\x18\x07 \x01(\x0b\x32\x1c.opi_api.security.v1.CaCerts\x12-\n\x07pubkeys\x18\x08 \x01(\x0b\x32\x1c.opi_api.security.v1.PubKeys\"\x93\x01\n\x10TrafficSelectors\x12\x41\n\x02ts\x18\x01 \x03(\x0b\x32\x35.opi_api.security.v1.TrafficSelectors.TrafficSelector\x1a<\n\x0fTrafficSelector\x12\x0c\n\x04\x63idr\x18\x01 \x01(\t\x12\r\n\x05proto\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\"\x15\n\x05\x41\x64\x64rs\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\"\xc9\x03\n\x05\x43hild\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x0c\x61g_proposals\x18\x02 \x01(\x0b\x32\x1e.opi_api.security.v1.Proposals\x12\x35\n\resp_proposals\x18\x03 \x01(\x0b\x32\x1e.opi_api.security.v1.Proposals\x12\x37\n\x08local_ts\x18\x04 \x01(\x0b\x32%.opi_api.security.v1.TrafficSelectors\x12\x38\n\tremote_ts\x18\x05 \x01(\x0b\x32%.opi_api.security.v1.TrafficSelectors\x12\x12\n\nrekey_time\x18\x06 \x01(\r\x12\x11\n\tlife_time\x18\x07 \x01(\r\x12\x11\n\trand_time\x18\x08 \x01(\r\x12\x0e\n\x06updown\x18\t \x01(\t\x12\x12\n\ninactivity\x18\n \x01(\r\x12\x0f\n\x07mark_in\x18\x0b \x01(\r\x12\x12\n\nmark_in_sa\x18\x0c \x01(\t\x12\x10\n\x08mark_out\x18\r \x01(\r\x12\x13\n\x0bset_mark_in\x18\x0e \x01(\r\x12\x14\n\x0cset_mark_out\x18\x0f \x01(\r\x12\x12\n\nhw_offload\x18\x10 \x01(\t\"\xd4\x04\n\nConnection\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12/\n\x0blocal_addrs\x18\x03 \x03(\x0b\x32\x1a.opi_api.security.v1.Addrs\x12\x30\n\x0cremote_addrs\x18\x04 \x03(\x0b\x32\x1a.opi_api.security.v1.Addrs\x12\x12\n\nlocal_port\x18\x05 \x01(\r\x12\x13\n\x0bremote_port\x18\x06 \x01(\r\x12\x31\n\tproposals\x18\x07 \x01(\x0b\x32\x1e.opi_api.security.v1.Proposals\x12\'\n\x04vips\x18\x08 \x01(\x0b\x32\x19.opi_api.security.v1.Vips\x12\x0c\n\x04\x64scp\x18\t \x01(\x04\x12\r\n\x05\x65ncap\x18\n \x01(\t\x12\x0e\n\x06mobike\x18\x0b \x01(\t\x12\x11\n\tdpd_delay\x18\x0c \x01(\r\x12\x13\n\x0b\x64pd_timeout\x18\r \x01(\r\x12\x13\n\x0breauth_time\x18\x0e \x01(\r\x12\x12\n\nrekey_time\x18\x0f \x01(\r\x12)\n\x05pools\x18\x10 \x01(\x0b\x32\x1a.opi_api.security.v1.Pools\x12\x32\n\nlocal_auth\x18\x11 \x01(\x0b\x32\x1e.opi_api.security.v1.LocalAuth\x12\x34\n\x0bremote_auth\x18\x12 \x01(\x0b\x32\x1f.opi_api.security.v1.RemoteAuth\x12,\n\x08\x63hildren\x18\x13 \x03(\x0b\x32\x1a.opi_api.security.v1.Child\"\x11\n\x0fIPsecVersionReq\"f\n\x10IPsecVersionResp\x12\x0e\n\x06\x64\x61\x65mon\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0f\n\x07sysname\x18\x03 \x01(\t\x12\x0f\n\x07release\x18\x04 \x01(\t\x12\x0f\n\x07machine\x18\x05 \x01(\t\"\x0f\n\rIPsecStatsReq\" \n\x0eIPsecStatsResp\x12\x0e\n\x06status\x18\x01 \x01(\t\"Q\n\x10IPsecInitiateReq\x12\r\n\x05\x63hild\x18\x01 \x01(\t\x12\x0b\n\x03ike\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\t\x12\x10\n\x08loglevel\x18\x04 \x01(\t\"\x13\n\x11IPsecInitiateResp\"\x83\x01\n\x11IPsecTerminateReq\x12\r\n\x05\x63hild\x18\x01 \x01(\t\x12\x0b\n\x03ike\x18\x02 \x01(\t\x12\x10\n\x08\x63hild_id\x18\x03 \x01(\x04\x12\x0e\n\x06ike_id\x18\x04 \x01(\x04\x12\r\n\x05\x66orce\x18\x05 \x01(\t\x12\x0f\n\x07timeout\x18\x06 \x01(\t\x12\x10\n\x08loglevel\x18\x07 \x01(\t\"J\n\x12IPsecTerminateResp\x12\x0f\n\x07success\x18\x01 \x01(\t\x12\x0f\n\x07matches\x18\x02 \x01(\r\x12\x12\n\nterminated\x18\x03 \x01(\r\"]\n\rIPsecRekeyReq\x12\r\n\x05\x63hild\x18\x01 \x01(\t\x12\x0b\n\x03ike\x18\x02 \x01(\t\x12\x10\n\x08\x63hild_id\x18\x03 \x01(\x04\x12\x0e\n\x06ike_id\x18\x04 \x01(\x04\x12\x0e\n\x06reauth\x18\x05 \x01(\t\"2\n\x0eIPsecRekeyResp\x12\x0f\n\x07success\x18\x01 \x01(\t\x12\x0f\n\x07matches\x18\x02 \x01(\r\"`\n\x0fIPsecListSasReq\x12\x0f\n\x07noblock\x18\x01 \x01(\t\x12\x0b\n\x03ike\x18\x02 \x01(\t\x12\x0e\n\x06ike_id\x18\x03 \x01(\x04\x12\r\n\x05\x63hild\x18\x04 \x01(\t\x12\x10\n\x08\x63hild_id\x18\x05 \x01(\x04\"\xe4\x02\n\x0bListChildSa\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\r\n\x05\x65ncap\x18\x03 \x01(\t\x12\x0e\n\x06spi_in\x18\x04 \x01(\t\x12\x0f\n\x07spi_out\x18\x05 \x01(\t\x12\x0e\n\x06\x63pi_in\x18\x06 \x01(\t\x12\x0f\n\x07\x63pi_out\x18\x07 \x01(\t\x12\x0f\n\x07mark_in\x18\x08 \x01(\t\x12\x14\n\x0cmark_mask_in\x18\t \x01(\t\x12\x10\n\x08mark_out\x18\n \x01(\t\x12\x15\n\rmark_mask_out\x18\x0b \x01(\t\x12\x10\n\x08if_id_in\x18\x0c \x01(\t\x12\x11\n\tif_id_out\x18\r \x01(\t\x12\x10\n\x08\x65ncr_alg\x18\x0e \x01(\t\x12\x14\n\x0c\x65ncr_keysize\x18\x0f \x01(\t\x12\x11\n\tinteg_alg\x18\x10 \x01(\t\x12\x15\n\rinteg_keysize\x18\x11 \x01(\t\x12\x10\n\x08\x64h_group\x18\x12 \x01(\t\x12\x0b\n\x03\x65sn\x18\x13 \x01(\t\"\xa6\x06\n\tListIkeSa\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08uniqueid\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x31\n\x08ikestate\x18\x04 \x01(\x0e\x32\x1f.opi_api.security.v1.IkeSaState\x12\x12\n\nlocal_host\x18\x05 \x01(\t\x12\x12\n\nlocal_port\x18\x06 \x01(\t\x12\x10\n\x08local_id\x18\x07 \x01(\t\x12\x13\n\x0bremote_host\x18\x08 \x01(\t\x12\x13\n\x0bremote_port\x18\t \x01(\t\x12\x11\n\tremote_id\x18\n \x01(\t\x12\x17\n\x0fremote_xauth_id\x18\x0b \x01(\t\x12\x15\n\rremote_eap_id\x18\x0c \x01(\t\x12\x11\n\tinitiator\x18\r \x01(\t\x12\x15\n\rinitiator_spi\x18\x0e \x01(\t\x12\x15\n\rresponder_spi\x18\x0f \x01(\t\x12\x11\n\tnat_local\x18\x10 \x01(\t\x12\x12\n\nnat_remote\x18\x11 \x01(\t\x12\x10\n\x08nat_fake\x18\x12 \x01(\t\x12\x0f\n\x07nat_any\x18\x13 \x01(\t\x12\x10\n\x08if_id_in\x18\x14 \x01(\t\x12\x11\n\tif_id_out\x18\x15 \x01(\t\x12\x10\n\x08\x65ncr_alg\x18\x16 \x01(\t\x12\x14\n\x0c\x65ncr_keysize\x18\x17 \x01(\t\x12\x11\n\tinteg_alg\x18\x18 \x01(\t\x12\x15\n\rinteg_keysize\x18\x19 \x01(\t\x12\x0f\n\x07prf_alg\x18\x1a \x01(\t\x12\x10\n\x08\x64h_group\x18\x1b \x01(\t\x12\x0b\n\x03ppk\x18\x1c \x01(\t\x12\x13\n\x0b\x65stablished\x18\x1d \x01(\t\x12\x12\n\nrekey_time\x18\x1e \x01(\t\x12\x13\n\x0breauth_time\x18\x1f \x01(\t\x12\x12\n\nlocal_vips\x18  \x03(\t\x12\x13\n\x0bremote_vips\x18! \x03(\t\x12\x14\n\x0ctasks_queued\x18\" \x03(\t\x12\x14\n\x0ctasks_active\x18# \x03(\t\x12\x15\n\rtasks_passive\x18$ \x03(\t\x12\x32\n\x08\x63hildsas\x18% \x03(\x0b\x32 .opi_api.security.v1.ListChildSa\"B\n\x10IPsecListSasResp\x12.\n\x06ikesas\x18\x01 \x03(\x0b\x32\x1e.opi_api.security.v1.ListIkeSa\" \n\x11IPsecListConnsReq\x12\x0b\n\x03ike\x18\x01 \x01(\t\"\xed\x02\n\x0cListConnAuth\x12\r\n\x05\x63lass\x18\x01 \x01(\t\x12\x0f\n\x07\x65\x61ptype\x18\x02 \x01(\t\x12\x11\n\teapvendor\x18\x03 \x01(\t\x12\r\n\x05xauth\x18\x04 \x01(\t\x12\x12\n\nrevocation\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\r\n\x05\x63\x61_id\x18\x07 \x01(\t\x12\x0e\n\x06\x61\x61\x61_id\x18\x08 \x01(\t\x12\x0e\n\x06\x65\x61p_id\x18\t \x01(\t\x12\x10\n\x08xauth_id\x18\n \x01(\t\x12*\n\x05group\x18\x0b \x01(\x0b\x32\x1b.opi_api.security.v1.Groups\x12\x34\n\x0b\x63\x65rt_policy\x18\x0c \x01(\x0b\x32\x1f.opi_api.security.v1.CertPolicy\x12)\n\x05\x63\x65rts\x18\r \x01(\x0b\x32\x1a.opi_api.security.v1.Certs\x12-\n\x07\x63\x61\x63\x65rts\x18\x0e \x01(\x0b\x32\x1c.opi_api.security.v1.CaCerts\"\xb8\x02\n\tListChild\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x12\n\nrekey_time\x18\x04 \x01(\r\x12\x13\n\x0brekey_bytes\x18\x05 \x01(\r\x12\x15\n\rrekey_packets\x18\x06 \x01(\r\x12\x12\n\ndpd_action\x18\x07 \x01(\t\x12\x14\n\x0c\x63lose_action\x18\x08 \x01(\t\x12\x37\n\x08local_ts\x18\t \x01(\x0b\x32%.opi_api.security.v1.TrafficSelectors\x12\x38\n\tremote_ts\x18\n \x01(\x0b\x32%.opi_api.security.v1.TrafficSelectors\x12\x11\n\tinterface\x18\x0b \x01(\t\x12\x10\n\x08priority\x18\x0c \x01(\t\"\xb5\x03\n\x0cListConnResp\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x0blocal_addrs\x18\x02 \x03(\x0b\x32\x1a.opi_api.security.v1.Addrs\x12\x30\n\x0cremote_addrs\x18\x03 \x03(\x0b\x32\x1a.opi_api.security.v1.Addrs\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x13\n\x0breauth_time\x18\x05 \x01(\r\x12\x12\n\nrekey_time\x18\x06 \x01(\r\x12\x0e\n\x06unique\x18\x07 \x01(\t\x12\x11\n\tdpd_delay\x18\x08 \x01(\r\x12\x13\n\x0b\x64pd_timeout\x18\t \x01(\r\x12\x0b\n\x03ppk\x18\n \x01(\t\x12\x14\n\x0cppk_required\x18\x0b \x01(\t\x12\x35\n\nlocal_auth\x18\x0c \x03(\x0b\x32!.opi_api.security.v1.ListConnAuth\x12\x36\n\x0bremote_auth\x18\r \x03(\x0b\x32!.opi_api.security.v1.ListConnAuth\x12\x30\n\x08\x63hildren\x18\x0e \x03(\x0b\x32\x1e.opi_api.security.v1.ListChild\"K\n\x12IPsecListConnsResp\x12\x35\n\nconnection\x18\x01 \x03(\x0b\x32!.opi_api.security.v1.ListConnResp\"@\n\x11IPsecListCertsReq\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04\x66lag\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\"\xce\x01\n\x08ListCert\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32$.opi_api.security.v1.CertificateType\x12\x36\n\x04\x66lag\x18\x02 \x01(\x0e\x32(.opi_api.security.v1.X509CertificateFlag\x12\x12\n\nhasprivkey\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\x12\x0f\n\x07subject\x18\x05 \x01(\t\x12\x11\n\tnotbefore\x18\x06 \x01(\t\x12\x10\n\x08notafter\x18\x07 \x01(\t\"B\n\x12IPsecListCertsResp\x12,\n\x05\x63\x65rts\x18\x01 \x03(\x0b\x32\x1d.opi_api.security.v1.ListCert\"G\n\x10IPsecLoadConnReq\x12\x33\n\nconnection\x18\x01 \x01(\x0b\x32\x1f.opi_api.security.v1.Connection\"$\n\x11IPsecLoadConnResp\x12\x0f\n\x07success\x18\x01 \x01(\t\"\"\n\x12IPsecUnloadConnReq\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x13IPsecUnloadConnResp\x12\x0f\n\x07success\x18\x01 \x01(\t*\x8a\x01\n\x0f\x43ryptoAlgorithm\x12\x0f\n\x0bNONE_CRYPTO\x10\x00\x12\n\n\x06\x41\x45S128\x10\x01\x12\n\n\x06\x41\x45S192\x10\x02\x12\n\n\x06\x41\x45S256\x10\x03\x12\x10\n\x0c\x41\x45S128GCM128\x10\x04\x12\x10\n\x0c\x41\x45S256GCM128\x10\x05\x12\x0e\n\nAES128GMAC\x10\x06\x12\x0e\n\nAES256GMAC\x10\x07*\x81\x01\n\x0eIntegAlgorithm\x12\x0e\n\nNONE_INTEG\x10\x00\x12\x07\n\x03MD5\x10\x01\x12\x0b\n\x07MD5_128\x10\x02\x12\x08\n\x04SHA1\x10\x03\x12\x0c\n\x08SHA1_160\x10\x04\x12\n\n\x06SHA256\x10\x05\x12\n\n\x06SHA384\x10\x07\x12\n\n\x06SHA512\x10\x08\x12\r\n\tSHA256_96\x10\t*\xdd\x01\n\x13\x44iffieHellmanGroups\x12\x11\n\rNONE_DH_GROUP\x10\x00\x12\x0b\n\x07MODP768\x10\x01\x12\x0c\n\x08MODP1024\x10\x02\x12\x0c\n\x08MODP1536\x10\x03\x12\x0c\n\x08MODP2048\x10\x04\x12\x0c\n\x08MODP3072\x10\x05\x12\x0c\n\x08MODP4096\x10\x06\x12\x0c\n\x08MODP6144\x10\x07\x12\x0c\n\x08MODP8192\x10\x08\x12\x10\n\x0cMODP1024S160\x10\t\x12\x10\n\x0cMODP2048S224\x10\n\x12\x10\n\x0cMODP2048S256\x10\x0b\x12\x0e\n\nCURVE25519\x10\x0c*\x8a\x01\n\x14PseudoRandomFunction\x12\x0c\n\x08NONE_PRF\x10\x00\x12\n\n\x06PRFMD5\x10\x01\x12\x0b\n\x07PRFSHA1\x10\x02\x12\x0e\n\nPRFAESXCBC\x10\x03\x12\x0e\n\nPRFAESCMAC\x10\x04\x12\r\n\tPRFSHA256\x10\x05\x12\r\n\tPRFSHA384\x10\x06\x12\r\n\tPRFSHA512\x10\x07*0\n\tIPsecMode\x12\x0f\n\x0bTUNNEL_MODE\x10\x00\x12\x12\n\x0eTRANSPORT_MODE\x10\x01*3\n\x08\x41uthType\x12\n\n\x06PUBKEY\x10\x00\x12\x07\n\x03PSK\x10\x01\x12\t\n\x05XAUTH\x10\x02\x12\x07\n\x03\x45\x41P\x10\x03*\x80\x01\n\nIkeSaState\x12\x0b\n\x07\x43REATED\x10\x00\x12\x0e\n\nCONNECTING\x10\x01\x12\x0f\n\x0b\x45STABLISHED\x10\x02\x12\x0b\n\x07PASSIVE\x10\x03\x12\x0c\n\x08REKEYING\x10\x04\x12\x0b\n\x07REKEYED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0e\n\nDESTROYING\x10\x07*\xea\x01\n\x0c\x43hildSaState\x12\x11\n\rCHILD_CREATED\x10\x00\x12\x10\n\x0c\x43HILD_ROUTED\x10\x01\x12\x14\n\x10\x43HILD_INSTALLING\x10\x02\x12\x13\n\x0f\x43HILD_INSTALLED\x10\x03\x12\x12\n\x0e\x43HILD_UPDATING\x10\x04\x12\x12\n\x0e\x43HILD_REKEYING\x10\x05\x12\x11\n\rCHILD_REKEYED\x10\x06\x12\x12\n\x0e\x43HILD_RETRYING\x10\x07\x12\x12\n\x0e\x43HILD_DELETING\x10\x08\x12\x11\n\rCHILD_DELETED\x10\t\x12\x14\n\x10\x43HILD_DESTROYING\x10\n*n\n\x0f\x43\x65rtificateType\x12\r\n\tCERT_X509\x10\x00\x12\x10\n\x0c\x43\x45RT_X509_AC\x10\x01\x12\x11\n\rCERT_X509_CRL\x10\x02\x12\x16\n\x12\x43\x45RT_OCSP_RESPONSE\x10\x03\x12\x0f\n\x0b\x43\x45RT_PUBKEY\x10\x04*u\n\x13X509CertificateFlag\x12\x17\n\x13X509_CERT_FLAG_NONE\x10\x00\x12\x15\n\x11X509_CERT_FLAG_CA\x10\x01\x12\x15\n\x11X509_CERT_FLAG_AA\x10\x02\x12\x17\n\x13X509_CERT_FLAG_OCSP\x10\x03\x32\xd2\x07\n\x05IPsec\x12]\n\x0cIPsecVersion\x12$.opi_api.security.v1.IPsecVersionReq\x1a%.opi_api.security.v1.IPsecVersionResp\"\x00\x12W\n\nIPsecStats\x12\".opi_api.security.v1.IPsecStatsReq\x1a#.opi_api.security.v1.IPsecStatsResp\"\x00\x12`\n\rIPsecInitiate\x12%.opi_api.security.v1.IPsecInitiateReq\x1a&.opi_api.security.v1.IPsecInitiateResp\"\x00\x12\x63\n\x0eIPsecTerminate\x12&.opi_api.security.v1.IPsecTerminateReq\x1a\'.opi_api.security.v1.IPsecTerminateResp\"\x00\x12W\n\nIPsecRekey\x12\".opi_api.security.v1.IPsecRekeyReq\x1a#.opi_api.security.v1.IPsecRekeyResp\"\x00\x12]\n\x0cIPsecListSas\x12$.opi_api.security.v1.IPsecListSasReq\x1a%.opi_api.security.v1.IPsecListSasResp\"\x00\x12\x63\n\x0eIPsecListConns\x12&.opi_api.security.v1.IPsecListConnsReq\x1a\'.opi_api.security.v1.IPsecListConnsResp\"\x00\x12\x63\n\x0eIPsecListCerts\x12&.opi_api.security.v1.IPsecListCertsReq\x1a\'.opi_api.security.v1.IPsecListCertsResp\"\x00\x12`\n\rIPsecLoadConn\x12%.opi_api.security.v1.IPsecLoadConnReq\x1a&.opi_api.security.v1.IPsecLoadConnResp\"\x00\x12\x66\n\x0fIPsecUnloadConn\x12\'.opi_api.security.v1.IPsecUnloadConnReq\x1a(.opi_api.security.v1.IPsecUnloadConnResp\"\x00\x42\x32Z0github.com/opiproject/opi-api/security/v1/gen/gob\x06proto3')

_CRYPTOALGORITHM = DESCRIPTOR.enum_types_by_name['CryptoAlgorithm']
CryptoAlgorithm = enum_type_wrapper.EnumTypeWrapper(_CRYPTOALGORITHM)
_INTEGALGORITHM = DESCRIPTOR.enum_types_by_name['IntegAlgorithm']
IntegAlgorithm = enum_type_wrapper.EnumTypeWrapper(_INTEGALGORITHM)
_DIFFIEHELLMANGROUPS = DESCRIPTOR.enum_types_by_name['DiffieHellmanGroups']
DiffieHellmanGroups = enum_type_wrapper.EnumTypeWrapper(_DIFFIEHELLMANGROUPS)
_PSEUDORANDOMFUNCTION = DESCRIPTOR.enum_types_by_name['PseudoRandomFunction']
PseudoRandomFunction = enum_type_wrapper.EnumTypeWrapper(_PSEUDORANDOMFUNCTION)
_IPSECMODE = DESCRIPTOR.enum_types_by_name['IPsecMode']
IPsecMode = enum_type_wrapper.EnumTypeWrapper(_IPSECMODE)
_AUTHTYPE = DESCRIPTOR.enum_types_by_name['AuthType']
AuthType = enum_type_wrapper.EnumTypeWrapper(_AUTHTYPE)
_IKESASTATE = DESCRIPTOR.enum_types_by_name['IkeSaState']
IkeSaState = enum_type_wrapper.EnumTypeWrapper(_IKESASTATE)
_CHILDSASTATE = DESCRIPTOR.enum_types_by_name['ChildSaState']
ChildSaState = enum_type_wrapper.EnumTypeWrapper(_CHILDSASTATE)
_CERTIFICATETYPE = DESCRIPTOR.enum_types_by_name['CertificateType']
CertificateType = enum_type_wrapper.EnumTypeWrapper(_CERTIFICATETYPE)
_X509CERTIFICATEFLAG = DESCRIPTOR.enum_types_by_name['X509CertificateFlag']
X509CertificateFlag = enum_type_wrapper.EnumTypeWrapper(_X509CERTIFICATEFLAG)
NONE_CRYPTO = 0
AES128 = 1
AES192 = 2
AES256 = 3
AES128GCM128 = 4
AES256GCM128 = 5
AES128GMAC = 6
AES256GMAC = 7
NONE_INTEG = 0
MD5 = 1
MD5_128 = 2
SHA1 = 3
SHA1_160 = 4
SHA256 = 5
SHA384 = 7
SHA512 = 8
SHA256_96 = 9
NONE_DH_GROUP = 0
MODP768 = 1
MODP1024 = 2
MODP1536 = 3
MODP2048 = 4
MODP3072 = 5
MODP4096 = 6
MODP6144 = 7
MODP8192 = 8
MODP1024S160 = 9
MODP2048S224 = 10
MODP2048S256 = 11
CURVE25519 = 12
NONE_PRF = 0
PRFMD5 = 1
PRFSHA1 = 2
PRFAESXCBC = 3
PRFAESCMAC = 4
PRFSHA256 = 5
PRFSHA384 = 6
PRFSHA512 = 7
TUNNEL_MODE = 0
TRANSPORT_MODE = 1
PUBKEY = 0
PSK = 1
XAUTH = 2
EAP = 3
CREATED = 0
CONNECTING = 1
ESTABLISHED = 2
PASSIVE = 3
REKEYING = 4
REKEYED = 5
DELETING = 6
DESTROYING = 7
CHILD_CREATED = 0
CHILD_ROUTED = 1
CHILD_INSTALLING = 2
CHILD_INSTALLED = 3
CHILD_UPDATING = 4
CHILD_REKEYING = 5
CHILD_REKEYED = 6
CHILD_RETRYING = 7
CHILD_DELETING = 8
CHILD_DELETED = 9
CHILD_DESTROYING = 10
CERT_X509 = 0
CERT_X509_AC = 1
CERT_X509_CRL = 2
CERT_OCSP_RESPONSE = 3
CERT_PUBKEY = 4
X509_CERT_FLAG_NONE = 0
X509_CERT_FLAG_CA = 1
X509_CERT_FLAG_AA = 2
X509_CERT_FLAG_OCSP = 3


_PROPOSALS = DESCRIPTOR.message_types_by_name['Proposals']
_VIPS = DESCRIPTOR.message_types_by_name['Vips']
_POOLS = DESCRIPTOR.message_types_by_name['Pools']
_CERTS = DESCRIPTOR.message_types_by_name['Certs']
_PUBKEYS = DESCRIPTOR.message_types_by_name['PubKeys']
_GROUPS = DESCRIPTOR.message_types_by_name['Groups']
_CERTPOLICY = DESCRIPTOR.message_types_by_name['CertPolicy']
_CACERTS = DESCRIPTOR.message_types_by_name['CaCerts']
_LOCALAUTH = DESCRIPTOR.message_types_by_name['LocalAuth']
_REMOTEAUTH = DESCRIPTOR.message_types_by_name['RemoteAuth']
_TRAFFICSELECTORS = DESCRIPTOR.message_types_by_name['TrafficSelectors']
_TRAFFICSELECTORS_TRAFFICSELECTOR = _TRAFFICSELECTORS.nested_types_by_name['TrafficSelector']
_ADDRS = DESCRIPTOR.message_types_by_name['Addrs']
_CHILD = DESCRIPTOR.message_types_by_name['Child']
_CONNECTION = DESCRIPTOR.message_types_by_name['Connection']
_IPSECVERSIONREQ = DESCRIPTOR.message_types_by_name['IPsecVersionReq']
_IPSECVERSIONRESP = DESCRIPTOR.message_types_by_name['IPsecVersionResp']
_IPSECSTATSREQ = DESCRIPTOR.message_types_by_name['IPsecStatsReq']
_IPSECSTATSRESP = DESCRIPTOR.message_types_by_name['IPsecStatsResp']
_IPSECINITIATEREQ = DESCRIPTOR.message_types_by_name['IPsecInitiateReq']
_IPSECINITIATERESP = DESCRIPTOR.message_types_by_name['IPsecInitiateResp']
_IPSECTERMINATEREQ = DESCRIPTOR.message_types_by_name['IPsecTerminateReq']
_IPSECTERMINATERESP = DESCRIPTOR.message_types_by_name['IPsecTerminateResp']
_IPSECREKEYREQ = DESCRIPTOR.message_types_by_name['IPsecRekeyReq']
_IPSECREKEYRESP = DESCRIPTOR.message_types_by_name['IPsecRekeyResp']
_IPSECLISTSASREQ = DESCRIPTOR.message_types_by_name['IPsecListSasReq']
_LISTCHILDSA = DESCRIPTOR.message_types_by_name['ListChildSa']
_LISTIKESA = DESCRIPTOR.message_types_by_name['ListIkeSa']
_IPSECLISTSASRESP = DESCRIPTOR.message_types_by_name['IPsecListSasResp']
_IPSECLISTCONNSREQ = DESCRIPTOR.message_types_by_name['IPsecListConnsReq']
_LISTCONNAUTH = DESCRIPTOR.message_types_by_name['ListConnAuth']
_LISTCHILD = DESCRIPTOR.message_types_by_name['ListChild']
_LISTCONNRESP = DESCRIPTOR.message_types_by_name['ListConnResp']
_IPSECLISTCONNSRESP = DESCRIPTOR.message_types_by_name['IPsecListConnsResp']
_IPSECLISTCERTSREQ = DESCRIPTOR.message_types_by_name['IPsecListCertsReq']
_LISTCERT = DESCRIPTOR.message_types_by_name['ListCert']
_IPSECLISTCERTSRESP = DESCRIPTOR.message_types_by_name['IPsecListCertsResp']
_IPSECLOADCONNREQ = DESCRIPTOR.message_types_by_name['IPsecLoadConnReq']
_IPSECLOADCONNRESP = DESCRIPTOR.message_types_by_name['IPsecLoadConnResp']
_IPSECUNLOADCONNREQ = DESCRIPTOR.message_types_by_name['IPsecUnloadConnReq']
_IPSECUNLOADCONNRESP = DESCRIPTOR.message_types_by_name['IPsecUnloadConnResp']
Proposals = _reflection.GeneratedProtocolMessageType('Proposals', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Proposals)
  })
_sym_db.RegisterMessage(Proposals)

Vips = _reflection.GeneratedProtocolMessageType('Vips', (_message.Message,), {
  'DESCRIPTOR' : _VIPS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Vips)
  })
_sym_db.RegisterMessage(Vips)

Pools = _reflection.GeneratedProtocolMessageType('Pools', (_message.Message,), {
  'DESCRIPTOR' : _POOLS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Pools)
  })
_sym_db.RegisterMessage(Pools)

Certs = _reflection.GeneratedProtocolMessageType('Certs', (_message.Message,), {
  'DESCRIPTOR' : _CERTS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Certs)
  })
_sym_db.RegisterMessage(Certs)

PubKeys = _reflection.GeneratedProtocolMessageType('PubKeys', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEYS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.PubKeys)
  })
_sym_db.RegisterMessage(PubKeys)

Groups = _reflection.GeneratedProtocolMessageType('Groups', (_message.Message,), {
  'DESCRIPTOR' : _GROUPS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Groups)
  })
_sym_db.RegisterMessage(Groups)

CertPolicy = _reflection.GeneratedProtocolMessageType('CertPolicy', (_message.Message,), {
  'DESCRIPTOR' : _CERTPOLICY,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.CertPolicy)
  })
_sym_db.RegisterMessage(CertPolicy)

CaCerts = _reflection.GeneratedProtocolMessageType('CaCerts', (_message.Message,), {
  'DESCRIPTOR' : _CACERTS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.CaCerts)
  })
_sym_db.RegisterMessage(CaCerts)

LocalAuth = _reflection.GeneratedProtocolMessageType('LocalAuth', (_message.Message,), {
  'DESCRIPTOR' : _LOCALAUTH,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.LocalAuth)
  })
_sym_db.RegisterMessage(LocalAuth)

RemoteAuth = _reflection.GeneratedProtocolMessageType('RemoteAuth', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEAUTH,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.RemoteAuth)
  })
_sym_db.RegisterMessage(RemoteAuth)

TrafficSelectors = _reflection.GeneratedProtocolMessageType('TrafficSelectors', (_message.Message,), {

  'TrafficSelector' : _reflection.GeneratedProtocolMessageType('TrafficSelector', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICSELECTORS_TRAFFICSELECTOR,
    '__module__' : 'ipsec_pb2'
    # @@protoc_insertion_point(class_scope:opi_api.security.v1.TrafficSelectors.TrafficSelector)
    })
  ,
  'DESCRIPTOR' : _TRAFFICSELECTORS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.TrafficSelectors)
  })
_sym_db.RegisterMessage(TrafficSelectors)
_sym_db.RegisterMessage(TrafficSelectors.TrafficSelector)

Addrs = _reflection.GeneratedProtocolMessageType('Addrs', (_message.Message,), {
  'DESCRIPTOR' : _ADDRS,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Addrs)
  })
_sym_db.RegisterMessage(Addrs)

Child = _reflection.GeneratedProtocolMessageType('Child', (_message.Message,), {
  'DESCRIPTOR' : _CHILD,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Child)
  })
_sym_db.RegisterMessage(Child)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.Connection)
  })
_sym_db.RegisterMessage(Connection)

IPsecVersionReq = _reflection.GeneratedProtocolMessageType('IPsecVersionReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECVERSIONREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecVersionReq)
  })
_sym_db.RegisterMessage(IPsecVersionReq)

IPsecVersionResp = _reflection.GeneratedProtocolMessageType('IPsecVersionResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECVERSIONRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecVersionResp)
  })
_sym_db.RegisterMessage(IPsecVersionResp)

IPsecStatsReq = _reflection.GeneratedProtocolMessageType('IPsecStatsReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECSTATSREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecStatsReq)
  })
_sym_db.RegisterMessage(IPsecStatsReq)

IPsecStatsResp = _reflection.GeneratedProtocolMessageType('IPsecStatsResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECSTATSRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecStatsResp)
  })
_sym_db.RegisterMessage(IPsecStatsResp)

IPsecInitiateReq = _reflection.GeneratedProtocolMessageType('IPsecInitiateReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECINITIATEREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecInitiateReq)
  })
_sym_db.RegisterMessage(IPsecInitiateReq)

IPsecInitiateResp = _reflection.GeneratedProtocolMessageType('IPsecInitiateResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECINITIATERESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecInitiateResp)
  })
_sym_db.RegisterMessage(IPsecInitiateResp)

IPsecTerminateReq = _reflection.GeneratedProtocolMessageType('IPsecTerminateReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECTERMINATEREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecTerminateReq)
  })
_sym_db.RegisterMessage(IPsecTerminateReq)

IPsecTerminateResp = _reflection.GeneratedProtocolMessageType('IPsecTerminateResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECTERMINATERESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecTerminateResp)
  })
_sym_db.RegisterMessage(IPsecTerminateResp)

IPsecRekeyReq = _reflection.GeneratedProtocolMessageType('IPsecRekeyReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECREKEYREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecRekeyReq)
  })
_sym_db.RegisterMessage(IPsecRekeyReq)

IPsecRekeyResp = _reflection.GeneratedProtocolMessageType('IPsecRekeyResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECREKEYRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecRekeyResp)
  })
_sym_db.RegisterMessage(IPsecRekeyResp)

IPsecListSasReq = _reflection.GeneratedProtocolMessageType('IPsecListSasReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLISTSASREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecListSasReq)
  })
_sym_db.RegisterMessage(IPsecListSasReq)

ListChildSa = _reflection.GeneratedProtocolMessageType('ListChildSa', (_message.Message,), {
  'DESCRIPTOR' : _LISTCHILDSA,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.ListChildSa)
  })
_sym_db.RegisterMessage(ListChildSa)

ListIkeSa = _reflection.GeneratedProtocolMessageType('ListIkeSa', (_message.Message,), {
  'DESCRIPTOR' : _LISTIKESA,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.ListIkeSa)
  })
_sym_db.RegisterMessage(ListIkeSa)

IPsecListSasResp = _reflection.GeneratedProtocolMessageType('IPsecListSasResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLISTSASRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecListSasResp)
  })
_sym_db.RegisterMessage(IPsecListSasResp)

IPsecListConnsReq = _reflection.GeneratedProtocolMessageType('IPsecListConnsReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLISTCONNSREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecListConnsReq)
  })
_sym_db.RegisterMessage(IPsecListConnsReq)

ListConnAuth = _reflection.GeneratedProtocolMessageType('ListConnAuth', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNAUTH,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.ListConnAuth)
  })
_sym_db.RegisterMessage(ListConnAuth)

ListChild = _reflection.GeneratedProtocolMessageType('ListChild', (_message.Message,), {
  'DESCRIPTOR' : _LISTCHILD,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.ListChild)
  })
_sym_db.RegisterMessage(ListChild)

ListConnResp = _reflection.GeneratedProtocolMessageType('ListConnResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.ListConnResp)
  })
_sym_db.RegisterMessage(ListConnResp)

IPsecListConnsResp = _reflection.GeneratedProtocolMessageType('IPsecListConnsResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLISTCONNSRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecListConnsResp)
  })
_sym_db.RegisterMessage(IPsecListConnsResp)

IPsecListCertsReq = _reflection.GeneratedProtocolMessageType('IPsecListCertsReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLISTCERTSREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecListCertsReq)
  })
_sym_db.RegisterMessage(IPsecListCertsReq)

ListCert = _reflection.GeneratedProtocolMessageType('ListCert', (_message.Message,), {
  'DESCRIPTOR' : _LISTCERT,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.ListCert)
  })
_sym_db.RegisterMessage(ListCert)

IPsecListCertsResp = _reflection.GeneratedProtocolMessageType('IPsecListCertsResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLISTCERTSRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecListCertsResp)
  })
_sym_db.RegisterMessage(IPsecListCertsResp)

IPsecLoadConnReq = _reflection.GeneratedProtocolMessageType('IPsecLoadConnReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLOADCONNREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecLoadConnReq)
  })
_sym_db.RegisterMessage(IPsecLoadConnReq)

IPsecLoadConnResp = _reflection.GeneratedProtocolMessageType('IPsecLoadConnResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECLOADCONNRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecLoadConnResp)
  })
_sym_db.RegisterMessage(IPsecLoadConnResp)

IPsecUnloadConnReq = _reflection.GeneratedProtocolMessageType('IPsecUnloadConnReq', (_message.Message,), {
  'DESCRIPTOR' : _IPSECUNLOADCONNREQ,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecUnloadConnReq)
  })
_sym_db.RegisterMessage(IPsecUnloadConnReq)

IPsecUnloadConnResp = _reflection.GeneratedProtocolMessageType('IPsecUnloadConnResp', (_message.Message,), {
  'DESCRIPTOR' : _IPSECUNLOADCONNRESP,
  '__module__' : 'ipsec_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.security.v1.IPsecUnloadConnResp)
  })
_sym_db.RegisterMessage(IPsecUnloadConnResp)

_IPSEC = DESCRIPTOR.services_by_name['IPsec']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/opiproject/opi-api/security/v1/gen/go'
  _CRYPTOALGORITHM._serialized_start=5963
  _CRYPTOALGORITHM._serialized_end=6101
  _INTEGALGORITHM._serialized_start=6104
  _INTEGALGORITHM._serialized_end=6233
  _DIFFIEHELLMANGROUPS._serialized_start=6236
  _DIFFIEHELLMANGROUPS._serialized_end=6457
  _PSEUDORANDOMFUNCTION._serialized_start=6460
  _PSEUDORANDOMFUNCTION._serialized_end=6598
  _IPSECMODE._serialized_start=6600
  _IPSECMODE._serialized_end=6648
  _AUTHTYPE._serialized_start=6650
  _AUTHTYPE._serialized_end=6701
  _IKESASTATE._serialized_start=6704
  _IKESASTATE._serialized_end=6832
  _CHILDSASTATE._serialized_start=6835
  _CHILDSASTATE._serialized_end=7069
  _CERTIFICATETYPE._serialized_start=7071
  _CERTIFICATETYPE._serialized_end=7181
  _X509CERTIFICATEFLAG._serialized_start=7183
  _X509CERTIFICATEFLAG._serialized_end=7300
  _PROPOSALS._serialized_start=37
  _PROPOSALS._serialized_end=278
  _VIPS._serialized_start=280
  _VIPS._serialized_end=299
  _POOLS._serialized_start=301
  _POOLS._serialized_end=322
  _CERTS._serialized_start=324
  _CERTS._serialized_end=345
  _PUBKEYS._serialized_start=347
  _PUBKEYS._serialized_end=372
  _GROUPS._serialized_start=374
  _GROUPS._serialized_end=397
  _CERTPOLICY._serialized_start=399
  _CERTPOLICY._serialized_end=432
  _CACERTS._serialized_start=434
  _CACERTS._serialized_end=459
  _LOCALAUTH._serialized_start=462
  _LOCALAUTH._serialized_end=670
  _REMOTEAUTH._serialized_start=673
  _REMOTEAUTH._serialized_end=995
  _TRAFFICSELECTORS._serialized_start=998
  _TRAFFICSELECTORS._serialized_end=1145
  _TRAFFICSELECTORS_TRAFFICSELECTOR._serialized_start=1085
  _TRAFFICSELECTORS_TRAFFICSELECTOR._serialized_end=1145
  _ADDRS._serialized_start=1147
  _ADDRS._serialized_end=1168
  _CHILD._serialized_start=1171
  _CHILD._serialized_end=1628
  _CONNECTION._serialized_start=1631
  _CONNECTION._serialized_end=2227
  _IPSECVERSIONREQ._serialized_start=2229
  _IPSECVERSIONREQ._serialized_end=2246
  _IPSECVERSIONRESP._serialized_start=2248
  _IPSECVERSIONRESP._serialized_end=2350
  _IPSECSTATSREQ._serialized_start=2352
  _IPSECSTATSREQ._serialized_end=2367
  _IPSECSTATSRESP._serialized_start=2369
  _IPSECSTATSRESP._serialized_end=2401
  _IPSECINITIATEREQ._serialized_start=2403
  _IPSECINITIATEREQ._serialized_end=2484
  _IPSECINITIATERESP._serialized_start=2486
  _IPSECINITIATERESP._serialized_end=2505
  _IPSECTERMINATEREQ._serialized_start=2508
  _IPSECTERMINATEREQ._serialized_end=2639
  _IPSECTERMINATERESP._serialized_start=2641
  _IPSECTERMINATERESP._serialized_end=2715
  _IPSECREKEYREQ._serialized_start=2717
  _IPSECREKEYREQ._serialized_end=2810
  _IPSECREKEYRESP._serialized_start=2812
  _IPSECREKEYRESP._serialized_end=2862
  _IPSECLISTSASREQ._serialized_start=2864
  _IPSECLISTSASREQ._serialized_end=2960
  _LISTCHILDSA._serialized_start=2963
  _LISTCHILDSA._serialized_end=3319
  _LISTIKESA._serialized_start=3322
  _LISTIKESA._serialized_end=4128
  _IPSECLISTSASRESP._serialized_start=4130
  _IPSECLISTSASRESP._serialized_end=4196
  _IPSECLISTCONNSREQ._serialized_start=4198
  _IPSECLISTCONNSREQ._serialized_end=4230
  _LISTCONNAUTH._serialized_start=4233
  _LISTCONNAUTH._serialized_end=4598
  _LISTCHILD._serialized_start=4601
  _LISTCHILD._serialized_end=4913
  _LISTCONNRESP._serialized_start=4916
  _LISTCONNRESP._serialized_end=5353
  _IPSECLISTCONNSRESP._serialized_start=5355
  _IPSECLISTCONNSRESP._serialized_end=5430
  _IPSECLISTCERTSREQ._serialized_start=5432
  _IPSECLISTCERTSREQ._serialized_end=5496
  _LISTCERT._serialized_start=5499
  _LISTCERT._serialized_end=5705
  _IPSECLISTCERTSRESP._serialized_start=5707
  _IPSECLISTCERTSRESP._serialized_end=5773
  _IPSECLOADCONNREQ._serialized_start=5775
  _IPSECLOADCONNREQ._serialized_end=5846
  _IPSECLOADCONNRESP._serialized_start=5848
  _IPSECLOADCONNRESP._serialized_end=5884
  _IPSECUNLOADCONNREQ._serialized_start=5886
  _IPSECUNLOADCONNREQ._serialized_end=5920
  _IPSECUNLOADCONNRESP._serialized_start=5922
  _IPSECUNLOADCONNRESP._serialized_end=5960
  _IPSEC._serialized_start=7303
  _IPSEC._serialized_end=8281
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import backend_aio_pb2 as backend__aio__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AioControllerServiceStub(object):
    """Back End (network-facing) APIs. This service is for AIO generic kernel block device.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAioController = channel.unary_unary(
                '/opi_api.storage.v1.AioControllerService/CreateAioController',
                request_serializer=backend__aio__pb2.CreateAioControllerRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.AioController.FromString,
                )
        self.DeleteAioController = channel.unary_unary(
                '/opi_api.storage.v1.AioControllerService/DeleteAioController',
                request_serializer=backend__aio__pb2.DeleteAioControllerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateAioController = channel.unary_unary(
                '/opi_api.storage.v1.AioControllerService/UpdateAioController',
                request_serializer=backend__aio__pb2.UpdateAioControllerRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.AioController.FromString,
                )
        self.ListAioControllers = channel.unary_unary(
                '/opi_api.storage.v1.AioControllerService/ListAioControllers',
                request_serializer=backend__aio__pb2.ListAioControllersRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.ListAioControllersResponse.FromString,
                )
        self.GetAioController = channel.unary_unary(
                '/opi_api.storage.v1.AioControllerService/GetAioController',
                request_serializer=backend__aio__pb2.GetAioControllerRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.AioController.FromString,
                )
        self.AioControllerStats = channel.unary_unary(
                '/opi_api.storage.v1.AioControllerService/AioControllerStats',
                request_serializer=backend__aio__pb2.AioControllerStatsRequest.SerializeToString,
                response_deserializer=backend__aio__pb2.AioControllerStatsResponse.FromString,
                )


class AioControllerServiceServicer(object):
    """Back End (network-facing) APIs. This service is for AIO generic kernel block device.
    """

    def CreateAioController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAioController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAioController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAioControllers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAioController(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AioControllerStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AioControllerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAioController': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAioController,
                    request_deserializer=backend__aio__pb2.CreateAioControllerRequest.FromString,
                    response_serializer=backend__aio__pb2.AioController.SerializeToString,
            ),
            'DeleteAioController': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAioController,
                    request_deserializer=backend__aio__pb2.DeleteAioControllerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateAioController': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAioController,
                    request_deserializer=backend__aio__pb2.UpdateAioControllerRequest.FromString,
                    response_serializer=backend__aio__pb2.AioController.SerializeToString,
            ),
            'ListAioControllers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAioControllers,
                    request_deserializer=backend__aio__pb2.ListAioControllersRequest.FromString,
                    response_serializer=backend__aio__pb2.ListAioControllersResponse.SerializeToString,
            ),
            'GetAioController': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAioController,
                    request_deserializer=backend__aio__pb2.GetAioControllerRequest.FromString,
                    response_serializer=backend__aio__pb2.AioController.SerializeToString,
            ),
            'AioControllerStats': grpc.unary_unary_rpc_method_handler(
                    servicer.AioControllerStats,
                    request_deserializer=backend__aio__pb2.AioControllerStatsRequest.FromString,
                    response_serializer=backend__aio__pb2.AioControllerStatsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.AioControllerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AioControllerService(object):
    """Back End (network-facing) APIs. This service is for AIO generic kernel block device.
    """

    @staticmethod
    def CreateAioController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioControllerService/CreateAioController',
            backend__aio__pb2.CreateAioControllerRequest.SerializeToString,
            backend__aio__pb2.AioController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAioController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioControllerService/DeleteAioController',
            backend__aio__pb2.DeleteAioControllerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAioController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioControllerService/UpdateAioController',
            backend__aio__pb2.UpdateAioControllerRequest.SerializeToString,
            backend__aio__pb2.AioController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAioControllers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioControllerService/ListAioControllers',
            backend__aio__pb2.ListAioControllersRequest.SerializeToString,
            backend__aio__pb2.ListAioControllersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAioController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioControllerService/GetAioController',
            backend__aio__pb2.GetAioControllerRequest.SerializeToString,
            backend__aio__pb2.AioController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AioControllerStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.AioControllerService/AioControllerStats',
            backend__aio__pb2.AioControllerStatsRequest.SerializeToString,
            backend__aio__pb2.AioControllerStatsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
